@@ -12,7 +12,7 @@ def inference(img_path,lang,model_rec,model_det):
         uniqueadd =["60:e3:2b:34:66:ce","a8:7e:ea:41:ad:34"]
         if macadd in uniqueadd:
             print("Configured Sucessfully")
-            ocr = PaddleOCR(use_angle_cls=True, lang=lang,use_gpu=False,rec_model_dir=model_rec,det_model_dir=model_det)
+            ocr = PaddleOCR(lang=lang,use_gpu=False,rec_model_dir=model_rec,det_model_dir=model_det)
             result = ocr.ocr(img_path, cls=True)
             txts = [line[1][0] for line in result]
             scores = [line[1][1] for line in result]
@@ -32,12 +32,11 @@ def inference(img_path,lang,model_rec,model_det):
             if len(txts)>1:           # if both txts are different
                 case=np.argmax(scores)
                 scores=[scores[case]]
-                txts=[txts[case]]
-            for i in txts:  
-                try:                  # if txts >20
-                    if float(i)>=20.0:
+                txts=[txts[case]]  
+            try:                  # if txts >20
+                    if float(i[0])>=20.0:
                         return "-2",float(0.0) #could not process
-                except:
+            except:
                     pass
             return str(txts[0]),float(scores[0])
         else:
